@@ -9,7 +9,10 @@ sub print {
     local(*option, *files) = @_;
 	local($tmpfile, *TMPFP);
 
+    %optionORIG = %option; # save the options, because they
+	                       # will be transformed while processing a single file
     foreach $file (@files) {
+		%option = %optionORIG; # take a fresh new copy of the options
 		if ($file eq '-') {
             #   copy stdin to temporary file
             &Util::Dbg("preprocess: STDIN -> tmpfile");
